@@ -32,7 +32,7 @@ from smartcard.scard import *
 def translateprotocolmask(protocol):
     """Translate CardConnection protocol mask into PCSC protocol mask."""
     pcscprotocol = 0
-    if None != protocol:
+    if protocol is not None:
         if CardConnection.T0_protocol & protocol:
             pcscprotocol |= SCARD_PROTOCOL_T0
         if CardConnection.T1_protocol & protocol:
@@ -47,7 +47,7 @@ def translateprotocolmask(protocol):
 def translateprotocolheader(protocol):
     """Translate protocol into PCSC protocol header."""
     pcscprotocol = 0
-    if None != protocol:
+    if protocol is not None:
         if CardConnection.T0_protocol == protocol:
             pcscprotocol = SCARD_PCI_T0
         if CardConnection.T1_protocol == protocol:
@@ -70,7 +70,7 @@ class PCSCCardConnection(CardConnection):
     def __init__(self, reader):
         """Construct a new PCSC card connection.
 
-        reader: the reader in which the smartcard to connect to is located.
+        @param reader: the reader in which the smartcard to connect to is located.
         """
         CardConnection.__init__(self, reader)
         self.hcard = None
@@ -86,7 +86,7 @@ class PCSCCardConnection(CardConnection):
         # can disappear before __del__ is called
         self.disconnect()
         hresult = SCardReleaseContext(self.hcontext)
-        if hresult != 0:
+        if hresult != 0 and hresult != SCARD_E_INVALID_VALUE:
             raise CardConnectionException(
                 'Failed to release context: ' + \
                 SCardGetErrorMessage(hresult))
@@ -104,11 +104,11 @@ class PCSCCardConnection(CardConnection):
         if 0 == pcscprotocol:
             pcscprotocol = self.getProtocol()
 
-        if mode == None:
+        if mode is None:
             mode = SCARD_SHARE_SHARED
 
         # store the way to dispose the card
-        if disposition == None:
+        if disposition is None:
             disposition = SCARD_UNPOWER_CARD
         self.disposition = disposition
 
@@ -146,18 +146,18 @@ class PCSCCardConnection(CardConnection):
 
         If disposition is not specified, do a warm reset (SCARD_RESET_CARD)"""
         CardConnection.reconnect(self, protocol)
-        if self.hcard == None:
+        if self.hcard is None:
             raise CardConnectionException('Card not connected')
 
         pcscprotocol = translateprotocolmask(protocol)
         if 0 == pcscprotocol:
             pcscprotocol = self.getProtocol()
 
-        if mode == None:
+        if mode is None:
             mode = SCARD_SHARE_SHARED
 
         # store the way to dispose the card
-        if disposition == None:
+        if disposition is None:
             disposition = SCARD_RESET_CARD
         self.disposition = disposition
 
@@ -195,18 +195,18 @@ class PCSCCardConnection(CardConnection):
             CardConnection.disconnect(self)
         except TypeError:
             pass
-        if None != self.hcard:
+        if self.hcard is not None:
             hresult = SCardDisconnect(self.hcard, self.disposition)
+            self.hcard = None
             if hresult != 0:
                 raise CardConnectionException(
                     'Failed to disconnect: ' + \
                     SCardGetErrorMessage(hresult))
-            self.hcard = None
 
     def getATR(self):
         """Return card ATR"""
         CardConnection.getATR(self)
-        if None == self.hcard:
+        if self.hcard is None:
             raise CardConnectionException('Card not connected')
         hresult, reader, state, protocol, atr = SCardStatus(self.hcard)
         if hresult != 0:
@@ -229,7 +229,7 @@ class PCSCCardConnection(CardConnection):
                     sw2 is status word 2, e.g. 0x1A
                     response are the response bytes excluding status words
         """
-        if None == protocol:
+        if protocol is None:
             protocol = self.getProtocol()
         CardConnection.doTransmit(self, bytes, protocol)
         pcscprotocolheader = translateprotocolheader(protocol)
@@ -239,7 +239,7 @@ class PCSCCardConnection(CardConnection):
                 'CardConnection.T0_protocol, ' + \
                 'CardConnection.T1_protocol, or ' + \
                 'CardConnection.RAW_protocol')
-        if None == self.hcard:
+        if self.hcard is None:
             raise CardConnectionException('Card not connected')
         hresult, response = SCardTransmit(
             self.hcard, pcscprotocolheader, bytes)
@@ -262,11 +262,11 @@ class PCSCCardConnection(CardConnection):
     def doControl(self, controlCode, bytes=[]):
         """Transmit a control command to the reader and return response.
 
-        controlCode: control command
+        @param controlCode: control command
 
-        bytes:       command data to transmit (list of bytes)
+        @param bytes:       command data to transmit (list of bytes)
 
-        return:      response are the response bytes (if any)
+        @return:      response are the response bytes (if any)
         """
         CardConnection.doControl(self, controlCode, bytes)
         hresult, response = SCardControl(self.hcard, controlCode, bytes)
@@ -280,9 +280,9 @@ class PCSCCardConnection(CardConnection):
     def doGetAttrib(self, attribId):
         """get an attribute
 
-        attribId: Identifier for the attribute to get
+        @param attribId: Identifier for the attribute to get
 
-        return:   response are the attribute byte array
+        @return:   response are the attribute byte array
         """
         CardConnection.doGetAttrib(self, attribId)
         hresult, response = SCardGetAttrib(self.hcard, attribId)
@@ -303,4 +303,3 @@ if __name__ == '__main__':
     print("%r %x %x" % cc.transmit(SELECT + DF_TELECOM))
 
     print(cc.control(CM_IOCTL_GET_FEATURE_REQUEST, []))
-
